==> discord.io-0.6.1.tar.gz: discord.io-0.6.1/discord/events/messages.py <==
# -*- coding: utf-8 -*-
# cython: language_level=3
# Copyright (c) 2021-present VincentRPS

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE
from discord.cache import Message
from discord.internal.dispatcher import Dispatcher
from discord.state import ConnectionState


class OnMessage:
    def __init__(self, data, dispatcher: Dispatcher, state: ConnectionState):
        ret = Message(data, state.app)
        state._sent_messages_cache[data["id"]] = data
        dispatcher.dispatch("MESSAGE", ret)


class OnMessageEdit:
    def __init__(self, data, dispatcher: Dispatcher, state: ConnectionState):
        try:
            before = Message(state._sent_messages_cache[data["id"]], state.app)
        except KeyError:
            # if the message is not in the cache we cant really save it.
            before = None
        state._edited_messages_cache[data["id"]] = data
        after = Message(data, state.app)
        dispatcher.dispatch("MESSAGE_EDIT", before, after)


class OnMessageDelete:
    def __init__(self, data, dispatcher: Dispatcher, state: ConnectionState):
        message = Message(state._sent_messages_cache[data["id"]], state.app)
        dispatcher.dispatch("MESSAGE_DELETE", message)

==> discord.io-0.6.2.tar.gz: discord.io-0.6.2/discord/events/messages.py <==
# -*- coding: utf-8 -*-
# cython: language_level=3
# Copyright (c) 2021-present VincentRPS

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE
from discord.cache import Message

from .core import Event


class OnMessage(Event):
    def process(self) -> None:
        ret = Message(self.data, self.state.app)
        self.state._sent_messages_cache[self.data["id"]] = self.data
        self.dispatch("MESSAGE", ret)


class OnMessageEdit(Event):
    def process(self):
        try:
            before = Message(
                self.state._sent_messages_cache[self.data["id"]], self.state.app
            )
        except KeyError:
            # if the message is not in the cache we cant really save it.
            before = None
        self.state._edited_messages_cache[self.data["id"]] = self.data
        after = Message(self.data, self.state.app)
        self.dispatch("MESSAGE_EDIT", before, after)


class OnMessageDelete(Event):
    def process(self):
        message = Message(
            self.state._sent_messages_cache[self.data["id"]], self.state.app
        )
        self.dispatch("MESSAGE_DELETE", message)
